import "./tasks/mapping.wdl" as mapping
import "./tasks/indexBam.wdl" as indexBam
import "./tasks/Metrics.wdl" as Metrics
import "./tasks/Dedup.wdl" as Dedup
import "./tasks/deduped_Metrics.wdl" as deduped_Metrics
import "./tasks/SplitReads.wdl" as SplitReads
import "./tasks/BQSR.wdl" as BQSR
import "./tasks/Haplotyper.wdl" as Haplotyper
import "./tasks/Hardfiltration.wdl" as Hardfiltration

workflow {{ project_name }} {

	File fastq_1
	File fastq_2
	File dbsnp_dir
	File dbsnp
	File dbmills_dir
	File db_mills
	File STARref_dir
    File ref_dir

	String SENTIEON_INSTALL_DIR
	String sample
	String fasta
	String disk_size
	String cluster_config


	call mapping.mapping as mapping {
		input: 
		sample=sample,
		STARref_dir=STARref_dir,
		ref_dir=ref_dir,
		fasta=fasta,
		fastq_1=fastq_1,
		fastq_2=fastq_2,
		disk_size=disk_size,
		cluster_config=cluster_config
	}

	call indexBam.indexBam as indexBam {
		input: 
		sample=sample,
		sorted_bam=mapping.sorted_bam,
		disk_size=disk_size,
		cluster_config=cluster_config
	}

	call Metrics.Metrics as Metrics {
		input:
		ref_dir=ref_dir,
		SENTIEON_INSTALL_DIR=SENTIEON_INSTALL_DIR,
		fasta=fasta,
		sorted_bam=mapping.sorted_bam,
		sorted_bam_index=indexBam.sorted_bam_index,		
		sample=sample,
		disk_size=disk_size,
		cluster_config=cluster_config
	}

	call Dedup.Dedup as Dedup {
		input:
		SENTIEON_INSTALL_DIR=SENTIEON_INSTALL_DIR,
		sorted_bam=mapping.sorted_bam,
		sorted_bam_index=indexBam.sorted_bam_index,		
		sample=sample,
		disk_size=disk_size,
		cluster_config=cluster_config
	}

	call deduped_Metrics.deduped_Metrics as deduped_Metrics {
		input:
		ref_dir=ref_dir,
		SENTIEON_INSTALL_DIR=SENTIEON_INSTALL_DIR,
		fasta=fasta,
		Dedup_bam=Dedup.Dedup_bam,
		Dedup_bam_index=Dedup.Dedup_bam_index,
		sample=sample,
		disk_size=disk_size,
		cluster_config=cluster_config
	}

	call SplitReads.SplitReads as SplitReads {
		input:
		ref_dir=ref_dir,
		SENTIEON_INSTALL_DIR=SENTIEON_INSTALL_DIR,
		fasta=fasta,
		Dedup_bam=Dedup.Dedup_bam,
		Dedup_bam_index=Dedup.Dedup_bam_index,
		sample=sample,
		disk_size=disk_size,
		cluster_config=cluster_config
	}
	
	call BQSR.BQSR as BQSR {
		input:
		SENTIEON_INSTALL_DIR=SENTIEON_INSTALL_DIR,
		ref_dir=ref_dir,
		fasta=fasta,
		dbsnp_dir=dbsnp_dir,
		dbsnp=dbsnp,
		dbmills_dir=dbmills_dir,
		db_mills=db_mills,
		Split_bam=SplitReads.Split_bam,
		Split_bam_index=SplitReads.Split_bam_index,
		sample=sample,
		disk_size=disk_size,
		cluster_config=cluster_config
	}

	call Haplotyper.Haplotyper as Haplotyper {
		input:
		SENTIEON_INSTALL_DIR=SENTIEON_INSTALL_DIR,
		fasta=fasta,
		recaled_bam=BQSR.recaled_bam,
		recaled_bam_index=BQSR.recaled_bam_index,
		dbsnp_dir=dbsnp_dir,
		dbsnp=dbsnp,
		ref_dir=ref_dir,
		sample=sample,
		disk_size=disk_size,
		cluster_config=cluster_config
	}

	call Hardfiltration.Hardfiltration as Hardfiltration {
		input:
		ref_dir=ref_dir,
		fasta=fasta,
		vcf_file=Haplotyper.vcf,
		vcf_index=Haplotyper.vcf_idx,
		sample=sample,
		disk_size=disk_size,
		cluster_config=cluster_config
	}

}

